@@ -1,6 +1,7 @@
 {
 package MyTest;
-our $USES_MITE = q[Mite::Class];
+our $USES_MITE = "Mite::Class";
+our $MITE_SHIM = "MyTest::Mite";
 use strict;
 use warnings;
 
@@ -12,21 +13,24 @@ sub new {
     my $args  = $meta->{HAS_BUILDARGS} ? $class->BUILDARGS( @_ ) : { ( @_ == 1 ) ? %{$_[0]} : @_ };
     my $no_build = delete $args->{__no_BUILD__};
 
-    # Initialize attributes
-    if ( exists($args->{q[list]}) ) { do { package MyTest::Mite; ref($args->{q[list]}) eq 'ARRAY' } or require Carp && Carp::croak(q[Type check failed in constructor: list should be ArrayRef]); $self->{q[list]} = $args->{q[list]};  } else { my $value = do { my $default_value = do { my $method = $MyTest::__list_DEFAULT__; $self->$method }; (ref($default_value) eq 'ARRAY') or do { require Carp; Carp::croak(q[Type check failed in default: list should be ArrayRef]) }; $default_value }; $self->{q[list]} = $value;  }
+        # Attribute: list
+    do { my $value = exists( $args->{"list"} ) ? $args->{"list"} : do { my $method = $MyTest::__list_DEFAULT__; $self->$method }; (ref($value) eq 'ARRAY') or MyTest::Mite::croak "Type check failed in constructor: %s should be %s", "list", "ArrayRef"; $self->{"list"} = $value; }; 
+
 
     # Enforce strict constructor
-    my @unknown = grep not( do { package MyTest::Mite; (defined and !ref and m{\A(?:list)\z}) } ), keys %{$args}; @unknown and require Carp and Carp::croak("Unexpected keys in constructor: " . join(q[, ], sort @unknown));
+    my @unknown = grep not( /\Alist\z/ ), keys %{$args}; @unknown and MyTest::Mite::croak( "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
 
     # Call BUILD methods
-    unless ( $no_build ) { $_->($self, $args) for @{ $meta->{BUILD} || [] } };
+    $self->BUILDALL( $args ) if ( ! $no_build and @{ $meta->{BUILD} || [] } );
 
     return $self;
 }
 
-defined ${^GLOBAL_PHASE}
-    or eval { require Devel::GlobalDestruction; 1 }
-    or do   { *Devel::GlobalDestruction::in_global_destruction = sub { undef; } };
+sub BUILDALL {
+    my $class = ref( $_[0] );
+    my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
+    $_->( @_ ) for @{ $meta->{BUILD} || [] };
+}
 
 sub DESTROY {
     my $self  = shift;
@@ -49,7 +53,6 @@ sub DESTROY {
 
 sub __META__ {
     no strict 'refs';
-    require mro;
     my $class      = shift; $class = ref($class) || $class;
     my $linear_isa = mro::get_linear_isa( $class );
     return {
@@ -62,6 +65,7 @@ sub __META__ {
             map { "$_\::DEMOLISH" } @$linear_isa
         ],
         HAS_BUILDARGS => $class->can('BUILDARGS'),
+        HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
     };
 }
 
@@ -83,11 +87,11 @@ my $__XS = !$ENV{MITE_PURE_PERL} && eval { require Class::XSAccessor; Class::XSA
 if ( $__XS ) {
     Class::XSAccessor->import(
         chained => 1,
-        getters => { q[list] => q[list] },
+        "getters" => { "list" => "list" },
     );
 }
 else {
-    *list = sub { @_ > 1 ? require Carp && Carp::croak("list is a read-only attribute of @{[ref $_[0]]}") : $_[0]{q[list]} };
+    *list = sub { @_ > 1 ? MyTest::Mite::croak( "list is a read-only attribute of @{[ref $_[0]]}" ) : $_[0]{"list"} };
 }
 
 
