@@ -1,12 +1,13 @@
 {
 package MyTest::Role2;
-our $USES_MITE = q[Mite::Role];
+our $USES_MITE = "Mite::Role";
+our $MITE_SHIM = "MyTest::Mite";
 use strict;
 use warnings;
 
 BEGIN {
     require MyTest::Role1;
-    our %DOES = ( q[MyTest::Role2] => 1, q[MyTest::Role1] => 1 );
+    our %DOES = ( "MyTest::Role2" => 1, "MyTest::Role1" => 1 );
 }
 
 sub DOES {
@@ -33,19 +34,21 @@ sub __FINALIZE_APPLICATION__ {
     $CONSUMERS{$target} = 1;
 
     my $type = do { no strict 'refs'; ${"$target\::USES_MITE"} };
-    if ( $type ne 'Mite::Class' ) {
-        return;
-    }
+    return if $type ne 'Mite::Class';
 
-    my @roles = ( q[MyTest::Role1] );
+    my @missing_methods;
+    @missing_methods = ()
+        and MyTest::Mite::croak( "$me requires $target to implement methods: " . join q[, ], @missing_methods );
+
+    my @roles = ( "MyTest::Role1" );
     my %nextargs = %{ $args || {} };
     ( $nextargs{-indirect} ||= 0 )++;
-    die "PANIC!" if $nextargs{-indirect} > 100;
+    MyTest::Mite::croak( "PANIC!" ) if $nextargs{-indirect} > 100;
     for my $role ( @roles ) {
         $role->__FINALIZE_APPLICATION__( $target, { %nextargs } );
     }
 
-    my $shim = q[MyTest::Mite];
+    my $shim = "MyTest::Mite";
     for my $modifier_rule ( @METHOD_MODIFIERS ) {
         my ( $modification, $names, $coderef ) = @$modifier_rule;
         $shim->$modification( $target, $names, $coderef );
